==> vtk6-6.3.0-2-aarch64.pkg.tar.xz: vtk/vtkHedgeHog.java <==
// java wrapper for vtkHedgeHog object
//

package vtk;
import vtk.*;

public class vtkHedgeHog extends vtkPolyDataAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetScaleFactor_2(double id0);
  public void SetScaleFactor(double id0)
    { SetScaleFactor_2(id0); }

  private native double GetScaleFactor_3();
  public double GetScaleFactor()
    { return GetScaleFactor_3(); }

  private native void SetVectorMode_4(int id0);
  public void SetVectorMode(int id0)
    { SetVectorMode_4(id0); }

  private native int GetVectorMode_5();
  public int GetVectorMode()
    { return GetVectorMode_5(); }

  private native void SetVectorModeToUseVector_6();
  public void SetVectorModeToUseVector()
    { SetVectorModeToUseVector_6(); }

  private native void SetVectorModeToUseNormal_7();
  public void SetVectorModeToUseNormal()
    { SetVectorModeToUseNormal_7(); }

  private native String GetVectorModeAsString_8();
  public String GetVectorModeAsString()
    { return GetVectorModeAsString_8(); }

  private native void SetOutputPointsPrecision_9(int id0);
  public void SetOutputPointsPrecision(int id0)
    { SetOutputPointsPrecision_9(id0); }

  private native int GetOutputPointsPrecision_10();
  public int GetOutputPointsPrecision()
    { return GetOutputPointsPrecision_10(); }

  public vtkHedgeHog() { super(); }

  public vtkHedgeHog(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-3-aarch64.pkg.tar.xz: vtk/vtkHedgeHog.java <==
// java wrapper for vtkHedgeHog object
//

package vtk;
import vtk.*;

public class vtkHedgeHog extends vtkPolyDataAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetScaleFactor_2(double id0);
  public void SetScaleFactor(double id0)
    { SetScaleFactor_2(id0); }

  private native double GetScaleFactor_3();
  public double GetScaleFactor()
    { return GetScaleFactor_3(); }

  private native void SetVectorMode_4(int id0);
  public void SetVectorMode(int id0)
    { SetVectorMode_4(id0); }

  private native int GetVectorMode_5();
  public int GetVectorMode()
    { return GetVectorMode_5(); }

  private native void SetVectorModeToUseVector_6();
  public void SetVectorModeToUseVector()
    { SetVectorModeToUseVector_6(); }

  private native void SetVectorModeToUseNormal_7();
  public void SetVectorModeToUseNormal()
    { SetVectorModeToUseNormal_7(); }

  private native String GetVectorModeAsString_8();
  public String GetVectorModeAsString()
    { return GetVectorModeAsString_8(); }

  private native void SetOutputPointsPrecision_9(int id0);
  public void SetOutputPointsPrecision(int id0)
    { SetOutputPointsPrecision_9(id0); }

  private native int GetOutputPointsPrecision_10();
  public int GetOutputPointsPrecision()
    { return GetOutputPointsPrecision_10(); }

  public vtkHedgeHog() { super(); }

  public vtkHedgeHog(long id) { super(id); }
  public native long   VTKInit();

}
